@@ -19,13 +19,9 @@
  */
 
 #include "config.h"
-#include "wine/port.h"
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef HAVE_UNISTD_H
-# include <unistd.h>
-#endif
 #include <string.h>
 #include <ctype.h>
 
@@ -110,6 +106,7 @@ static void write_function_stub( const type_t *iface, const var_t *func,
     if (has_full_pointer)
         write_full_pointer_free(client, indent, func);
 
+    if (interpreted_mode) print_client("NdrCorrelationFree(&__frame->_StubMsg);\n");
     print_client("NdrFreeBuffer(&__frame->_StubMsg);\n");
 
     if (explicit_fc == FC_BIND_GENERIC)
@@ -138,6 +135,7 @@ static void write_function_stub( const type_t *iface, const var_t *func,
         write_type_decl(client, &retval->declspec, retval->name);
         fprintf(client, ";\n");
     }
+    if (interpreted_mode) print_client("ULONG _NdrCorrCache[256];\n");
     print_client("RPC_MESSAGE _RpcMessage;\n");
 
     if (handle_var)
@@ -217,6 +215,8 @@ static void write_function_stub( const type_t *iface, const var_t *func,
         }
         break;
     }
+    if (interpreted_mode)
+        print_client( "NdrCorrelationInitialize(&__frame->_StubMsg, _NdrCorrCache, sizeof(_NdrCorrCache), 0);\n" );
 
     write_remoting_arguments(client, indent, func, "", PASS_IN, PHASE_BUFFERSIZE);
 
@@ -289,7 +289,6 @@ static void write_function_stub( const type_t *iface, const var_t *func,
 static void write_serialize_function(FILE *file, const type_t *type, const type_t *iface,
                                      const char *func_name, const char *ret_type)
 {
-    enum stub_mode mode = get_stub_mode();
     static int emitted_pickling_info;
 
     if (iface && !type->typestring_offset)
@@ -300,7 +299,7 @@ static void write_serialize_function(FILE *file, const type_t *type, const type_
         return;
     }
 
-    if (!emitted_pickling_info && iface && mode != MODE_Os)
+    if (!emitted_pickling_info && iface && interpreted_mode)
     {
         fprintf(file, "static const MIDL_TYPE_PICKLING_INFO __MIDL_TypePicklingInfo =\n");
         fprintf(file, "{\n");
@@ -322,9 +321,9 @@ static void write_serialize_function(FILE *file, const type_t *type, const type_
 
     fprintf(file, "{\n");
     fprintf(file, "    %sNdrMesType%s%s(\n", ret_type ? "return " : "", func_name,
-            mode != MODE_Os ? "2" : "");
+            interpreted_mode ? "2" : "");
     fprintf(file, "        IDL_handle,\n");
-    if (mode != MODE_Os)
+    if (interpreted_mode)
         fprintf(file, "        (MIDL_TYPE_PICKLING_INFO*)&__MIDL_TypePicklingInfo,\n");
     fprintf(file, "        &%s_StubDesc,\n", iface->name);
     fprintf(file, "        (PFORMAT_STRING)&__MIDL_TypeFormatString.Format[%u],\n",
@@ -422,7 +421,7 @@ static void write_stubdescriptor(type_t *iface, int expr_eval_routines)
     print_client("0,\n");
     print_client("__MIDL_TypeFormatString.Format,\n");
     print_client("1, /* -error bounds_check flag */\n");
-    print_client("0x%x, /* Ndr library version */\n", get_stub_mode() == MODE_Oif ? 0x50002 : 0x10001);
+    print_client("0x%x, /* Ndr library version */\n", interpreted_mode ? 0x50002 : 0x10001);
     print_client("0,\n");
     print_client("0x50200ca, /* MIDL Version 5.2.202 */\n");
     print_client("0,\n");
@@ -441,7 +440,7 @@ static void write_stubdescriptor(type_t *iface, int expr_eval_routines)
 static void write_clientinterfacedecl(type_t *iface)
 {
     unsigned int ver = get_attrv(iface->attrs, ATTR_VERSION);
-    const UUID *uuid = get_attrp(iface->attrs, ATTR_UUID);
+    const struct uuid *uuid = get_attrp(iface->attrs, ATTR_UUID);
     const str_list_t *endpoints = get_attrp(iface->attrs, ATTR_ENDPOINT);
 
     if (endpoints) write_endpoints( client, iface->name, endpoints );
@@ -472,10 +471,10 @@ static void write_clientinterfacedecl(type_t *iface)
     indent--;
     print_client("};\n");
     if (old_names)
-        print_client("RPC_IF_HANDLE %s_ClientIfHandle DECLSPEC_HIDDEN = (RPC_IF_HANDLE)& %s___RpcClientInterface;\n",
+        print_client("RPC_IF_HANDLE %s_ClientIfHandle = (RPC_IF_HANDLE)& %s___RpcClientInterface;\n",
                      iface->name, iface->name);
     else
-        print_client("RPC_IF_HANDLE %s%s_v%d_%d_c_ifspec DECLSPEC_HIDDEN = (RPC_IF_HANDLE)& %s___RpcClientInterface;\n",
+        print_client("RPC_IF_HANDLE %s%s_v%d_%d_c_ifspec = (RPC_IF_HANDLE)& %s___RpcClientInterface;\n",
                      prefix_client, iface->name, MAJORVERSION(ver), MINORVERSION(ver), iface->name);
     fprintf(client, "\n");
 }
@@ -504,10 +503,6 @@ static void init_client(void)
     print_client( "\n");
     print_client("#include \"%s\"\n", header_name);
     print_client( "\n");
-    print_client( "#ifndef DECLSPEC_HIDDEN\n");
-    print_client( "#define DECLSPEC_HIDDEN\n");
-    print_client( "#endif\n");
-    print_client( "\n");
 }
 
 
